@@ -1,3 +1,3 @@
 #' @rdname cplot
 #' @export
-cplot.glm <- cplot.lm
+cplot.glm <- cplot.default
